from distutils.core import setup

setup (
	name ='Listing',
	version = "1.2.0",
	py_modules = ['Listing'],
	author = "Santanu",
	author_email = "ghosalsantanuit@gmail.com",
	url = "http://wastelandersdiary.blogspot.com/",
	description = "A Simple Python List Reader using Nested Function"
	)
